@@ -36,23 +36,56 @@ class PinyinLookup() :
                 self.spliter.beginCharSet.add( newKey[0] ) 
                 self.spliter.pinyinTree.addPath( newKey )
             self.fitter.dictTree.addKey( newKey )
+    def subFit( self, fitList, pinyinStringList ) :
+        subFitPoint = -999
+        #for key in fitList :
+        for i in range( len( fitList ) ) :
+            key = fitList[i]
+            #currentSubFitPoint = len( key ) - key.count( "'" ) - len( self.spliter.code )
+            currentSubFitPoint = key.count( "'" ) + 1 - len( pinyinStringList[i].string )
+            #print key, pinyinStringList[i].string, currentSubFitPoint
+            if currentSubFitPoint > 0 :
+                currentSubFitPoint = -998
+            if currentSubFitPoint > subFitPoint :
+                subFitPoint = currentSubFitPoint
+            #print key, currentSubFitPoint, subFitPoint
+        newFitList = []
+        preeditList = []
+        for i in range( len( fitList ) ) :
+            key = fitList[i]
+            currentSubFitPoint = key.count( "'" ) + 1 - len( pinyinStringList[i].string )
+            if currentSubFitPoint >= subFitPoint :
+                newFitList.append( key )
+                preeditList.append( str( pinyinStringList[i] ) )
+        #print newFitList, newPreeditList
+        return newFitList, preeditList
     def append( self, code ) :
+        #print "append", code
         self.spliter.append( code )
         fitList = []
-        preeditList = []
+        #preeditList = []
+        pinyinStringList = []
         fitPoint = -999
         for pinyinString in self.spliter.stack :
-            currentFitPoint, keys = self.fitter.fit( pinyinString.string )
-            #print currentFitPoint, keys
-            if currentFitPoint > fitPoint :
-                fitList = []
-                fitList.extend( keys )
-                fitPoint = currentFitPoint
-                preeditList = []
-                preeditList.extend( [ str( pinyinString ) ] * len( keys ) )
-            elif currentFitPoint == fitPoint :
-                fitList.extend( keys )
-                preeditList.extend( [ str( pinyinString ) ] * len( keys ) )
+            #print pinyinString
+            if pinyinString.length < len( self.spliter.code ) :
+                pass
+            else :
+                currentFitPoint, keys = self.fitter.fit( pinyinString.string )
+                #print currentFitPoint, keys
+                if currentFitPoint > fitPoint :
+                    fitPoint = currentFitPoint
+                    fitList = []
+                    preeditList = []
+                    fitList.extend( keys )
+                    #preeditList.extend( [ str( pinyinString ) ] * len( keys ) )
+                    pinyinStringList.extend( [ pinyinString ] * len( keys ) )
+                elif currentFitPoint == fitPoint :
+                    fitList.extend( keys )
+                    #preeditList.extend( [ str( pinyinString ) ] * len( keys ) )
+                    pinyinStringList.extend( [ pinyinString ] * len( keys ) )
+        fitList, preeditList = self.subFit( fitList, pinyinStringList )
+        #print fitList
         self.picker.set( fitList, preeditList, True )
         cache = [ fitPoint, fitList, preeditList ] 
         self.cache.append( cache )
@@ -113,10 +146,11 @@ class PinyinLookup() :
         self.candCacheIndex = 0
         self.candStartIndex = 0
 
+
 if __name__ == "__main__" :
     import sys
     lookup = PinyinLookup()
-    lookup.load( "../../data/new_formated" )
+    lookup.load( "../../data/formated" )
     while (1) :
         code = sys.stdin.readline()[:-1]
         for c in code :
